@@ -501,6 +501,7 @@ SystemProc *PrepareProc(BOOL NeedForCall)
             // Types
             case 'v':
             case 'V': temp2 = PAT_VOID; break;
+            case 'p':
             case 'i':
             case 'I': temp2 = PAT_INT; break;
             case 'l':
@@ -870,10 +871,11 @@ void ParamsOut(SystemProc *proc)
             }
             break;
         case PAT_GUID:
-            wstr = (LPWSTR) GlobalAlloc(GPTR, g_stringsize*2);
-            StringFromGUID2(*((REFGUID*)place), wstr, g_stringsize*2);
-            WideCharToMultiByte(CP_ACP, 0, wstr, g_stringsize, realbuf, g_stringsize, NULL, NULL); 
-            GlobalFree((HGLOBAL)wstr);
+            {
+              WCHAR guidstrbuf[39]; 
+              int guidcch = StringFromGUID2(*((REFGUID*)place), guidstrbuf, 39);
+              WideCharToMultiByte(CP_ACP, 0, guidstrbuf, guidcch, realbuf, g_stringsize, NULL, NULL); 
+            }
             break;
         case PAT_WSTRING:
             wstr = *((LPWSTR*)place);
@@ -1022,7 +1024,7 @@ failure is raised if _osplatform is not set. The assertion is reported by
 the same means as used for the _RPT0 macro. This leads to an endless recursion.
 */
 
-BOOL WINAPI DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
+BOOL WINAPI DllMain(HINSTANCE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 {
         g_hInstance=hInst;
         
