@@ -546,7 +546,7 @@ static bool GetDLLVersionUsingRE(const string& filepath, DWORD& high, DWORD & lo
         // get VS_FIXEDFILEINFO from VS_VERSIONINFO
         WCHAR *szKey = (WCHAR *)(ver + sizeof(WORD) * 3);
         int len = (winchar_strlen(szKey) + 1) * sizeof(WCHAR) + sizeof(WORD) * 3;
-        len = (len + 3) & ~3; // align on DWORD boundry
+        len = (len + 3) & ~3; // align on DWORD boundary
         VS_FIXEDFILEINFO *verinfo = (VS_FIXEDFILEINFO *)(ver + len);
         if (versize > len && verinfo->dwSignature == VS_FFI_SIGNATURE)
         {
@@ -780,7 +780,7 @@ static DWORD GetVxdVersionInfoSize( LPCSTR szFile )
 
     // GetVxdVersion() will fail with ERROR_INSUFFICIENT_BUFFER and
     // the required buffer size will be returned in dwResult.
-    if ( GetLastError() == ERROR_INSUFFICIENT_BUFFER ) 
+    if ( dwError == ERROR_INSUFFICIENT_BUFFER ) 
     {
       SetLastError( 0 );
       return dwResult;
